%global commit		b50fd91ba0aeea2067dc9d82e6c352dbe0210eb3
%global shortcommit	%(c=%{commit}; echo ${c:0:7})
Name:           libfplll
Version:        4.0.5
Release:        1%{?dist}
Summary:        LLL-reduces euclidean lattices
License:        LGPLv2+
URL:            https://github.com/dstehle/fplll
Source0:        https://github.com/dstehle/fplll/archive/%{commit}.tar.gz#/fplll-%{shortcommit}.tar.gz
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
BuildRequires:  mpfr-devel

%description
fplll contains several algorithms on lattices that rely on
floating-point computations. This includes implementations of the
floating-point LLL reduction algorithm, offering different
speed/guarantees ratios. It contains a 'wrapper' choosing the
estimated best sequence of variants in order to provide a guaranteed
output as fast as possible. In the case of the wrapper, the
succession of variants is oblivious to the user. It also includes
a rigorous floating-point implementation of the Kannan-Fincke-Pohst
algorithm that finds a shortest non-zero lattice vector, and the BKZ
reduction algorithm.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        tools
Summary:        Command line tools that use %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    tools
The %{name}-tools package contains command-line tools that expose
the functionality of %{name}.


%prep
%setup -q -n fplll-%{commit}
./autogen.sh

%build
%configure --disable-static LDFLAGS="-Wl,--as-needed $RPM_LD_FLAGS"

# Eliminate hardcoded rpaths, and workaround libtool moving all -Wl options
# after the libraries to be linked
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|-nostdlib|-Wl,--as-needed &|' \
    -i libtool

make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la


%check
export LD_LIBRARY_PATH=$PWD/src/.libs
make check


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/*.so.*

%files devel
%{_includedir}/fplll.h
%{_includedir}/fplll/
%{_libdir}/*.so
%{_libdir}/pkgconfig/fplll.pc

%files tools
%{_bindir}/*


%changelog
* Tue Aug  9 2016 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.0.5-1
- Update to version required by sagemath 7.3

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 4.0.4-6
- Rebuilt for GCC 5 C++11 ABI change

* Tue Feb 17 2015 Jerry James <loganjerry@gmail.com> - 4.0.4-5
- Update project URL
- Use license macro

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri May 31 2013 Jerry James <loganjerry@gmail.com> - 4.0.4-1
- New upstream release
- All patches have been upstreamed

* Mon May  6 2013 Jerry James <loganjerry@gmail.com> - 4.0.3-1
- New upstream release

* Tue Mar 26 2013 Jerry James <loganjerry@gmail.com> - 4.0.2-2
- Add support for aarch64 (bz 925727)

* Mon Jan 28 2013 Jerry James <loganjerry@gmail.com> - 4.0.2-1
- New upstream release

* Sat Oct 20 2012 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.0.1-2
- Add extra compatibility support with fplll3 (#868579)

* Thu Sep 27 2012 Jerry James <loganjerry@gmail.com> - 4.0.1-1
- New upstream release
- Separate binaries into a -tools subpackage
- Modernize the spec file

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.12-5.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.12-4.2
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.12-3.2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Oct 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 3.0.12-2.2
- rebuild with new gmp without compat lib

* Wed Oct 12 2011 Peter Schiffer <pschiffe@redhat.com> - 3.0.12-2.1
- rebuild with new gmp

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Aug 8 2009 Conrad Meyer <konrad@tylerc.org> - 3.0.12-1
- Bump to new version (3.0.12).

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Dec 12 2008 Conrad Meyer <konrad@tylerc.org> - 3.0.11-1
- Bump to new version (3.0.11).

* Fri Oct 17 2008 Conrad Meyer <konrad@tylerc.org> - 3.0.9-2
- Rename 'generate' binary to 'fplll_generate'.
- Move generically-named header files to fplll subdirectory of includedir.
- Add %%check.

* Sun Oct 12 2008 Conrad Meyer <konrad@tylerc.org> - 3.0.9-1
- Initial package.
